@@ -32,6 +32,16 @@ def add_event(event_collection, body, timestamp=None):
     _client.add_event(event_collection, body, timestamp=timestamp)
 
 
+def add_events(events):
+    _initialize_client_from_environment()
+    _client.add_events(events)
+
+
+def generate_image_beacon(event_collection, body, timestamp=None):
+    _initialize_client_from_environment()
+    return _client.generate_image_beacon(event_collection, body, timestamp=timestamp)
+
+
 def count(event_collection, timeframe=None, timezone=None, interval=None, filters=None, group_by=None):
     """ Performs a count query
 
